@@ -209,6 +209,7 @@ class AxiStreamHandler():
 
 
     def __init_channels(self):
+        print("Initializing channels")
         self.sendchannel = self.overlay.axi_dma_0.sendchannel
         self.recvchannel = self.overlay.axi_dma_0.recvchannel
 
@@ -256,6 +257,8 @@ class AxiStreamHandler():
             self.datatype = "np.float32"
         elif (self.model_specs["data_type"] == "fps16f6"):
             self.datatype = "np.fps16f6"
+        elif (self.model_specs["data_type"] == "fps32f16"):
+            self.datatype = "np.fps32f16"
         elif (self.model_specs["data_type"].startswith("flpe")):
             print("Data type is flopoco since it starts with flpe")
             self.datatype = self.__initialize_datatype_flopoco(self.model_specs["data_type"])
@@ -269,6 +272,8 @@ class AxiStreamHandler():
             return np.float32, np.uint32
         elif (self.model_specs["data_type"] == "fps16f6"):
             return np.int16, np.int16
+        elif (self.model_specs["data_type"] == "fps32f16"):
+            return np.int32, np.int32
         elif (self.model_specs["data_type"].startswith("flpe")):
             if self.datatype == "np.uint8" or self.datatype == "np.uint16":
                 return np.uint16, np.uint16
@@ -393,6 +398,8 @@ class AxiStreamHandler():
                 self.recvchannel.transfer(output_buffer)
                 self.sendchannel.wait()
                 self.recvchannel.wait()
+                print("After transfer")
+                print("output buffer: ", output_buffer)
                 if debug:
                     end_time = time.time()
                     time_diff = (end_time - start_time) * 1000
